@@ -1,10 +1,5 @@
 ##
-# Copyright 2009-2012 Ghent University
-# Copyright 2009-2012 Stijn De Weirdt
-# Copyright 2010 Dries Verdegem
-# Copyright 2010-2012 Kenneth Hoste
-# Copyright 2011 Pieter De Baets
-# Copyright 2011-2012 Jens Timmerman
+# Copyright 2009-2013 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -29,15 +24,25 @@
 ##
 """
 EasyBuild support for building and installing ATLAS, implemented as an easyblock
+
+@author: Stijn De Weirdt (Ghent University)
+@author: Dries Verdegem (Ghent University)
+@author: Kenneth Hoste (Ghent University)
+@author: Pieter De Baets (Ghent University)
+@author: Jens Timmerman (Ghent University)
 """
 
+import fileinput
 import re
 import os
+import sys
+from distutils.version import LooseVersion
 
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.framework.easyconfig import CUSTOM
 from easybuild.tools.filetools import run_cmd
 from easybuild.tools.modules import get_software_root
+from easybuild.tools.systemtools import get_cpu_speed
 
 
 class EB_ATLAS(ConfigureMake):
@@ -69,17 +74,47 @@ class EB_ATLAS(ConfigureMake):
             # ignore CPU throttling check
             # this is not recommended, it will disturb the measurements done by ATLAS
             # used for the EasyBuild demo, to avoid requiring root privileges
-            self.cfg.update('configopts', '-Si cputhrchk 0')
+            if LooseVersion(self.version) < LooseVersion('3.10.0'):
+                self.cfg.update('configopts', '-Si cputhrchk 0')
+            else:
+                self.log.warning("Ignore CPU throttling check is not possible via command line.")
+                # apply patch to ignore CPU throttling: make ProbeCPUThrottle always return 0
+                # see http://sourceforge.net/p/math-atlas/support-requests/857/
+                cfg_file = os.path.join('CONFIG', 'src', 'config.c')
+                for line in fileinput.input(cfg_file, inplace=1, backup='.orig.eb'):
+                    line = re.sub(r"^(\s*iret)\s*=\s*.*CPU THROTTLE.*$", r"\1 = 0;", line)
+                    sys.stdout.write(line)
+            self.log.warning('CPU throttling check ignored: NOT recommended!')
+
+        # use cycle accurate timer for timings
+        # see http://math-atlas.sourceforge.net/atlas_install/node23.html
+        # this should work on Linux with both GCC and Intel compilers
+        cpu_freq = int(get_cpu_speed())
+        self.cfg.update('configopts', "-D c -DPentiumCPS=%s" % cpu_freq)
+
 
         # if LAPACK is found, instruct ATLAS to provide a full LAPACK library
         # ATLAS only provides a few LAPACK routines natively
         if self.cfg['full_lapack']:
-            lapack = get_software_root('LAPACK')
-            if lapack:
-                self.cfg.update('configopts', ' --with-netlib-lapack=%s/lib/liblapack.a' % lapack)
+            lapack_lib_version = LooseVersion('3.9')
+            if LooseVersion(self.version) < lapack_lib_version:
+                # pass built LAPACK library
+                lapack = get_software_root('LAPACK')
+                if lapack:
+                    self.cfg.update('configopts', ' --with-netlib-lapack=%s/lib/liblapack.a' % lapack)
+                else:
+                    self.log.error("netlib's LAPACK library not available,"\
+                                   " required to build ATLAS with a full LAPACK library.")
             else:
-                self.log.error("netlib's LAPACK library not available,"\
-                               " required to build ATLAS with a full LAPACK library.")
+                # pass LAPACK source tarball
+                lapack_src = None
+                for src in self.src:
+                    if src['name'].startswith('lapack'):
+                        lapack_src = src['path']
+                if lapack_src is not None:
+                    self.cfg.update('configopts', ' --with-netlib-lapack-tarfile=%s' % lapack_src)
+                else:
+                    self.log.error("LAPACK source tarball not available, but required.")
 
         # enable building of shared libraries (requires -fPIC)
         if self.cfg['sharedlibs'] or self.toolchain.options['pic']:
@@ -205,7 +240,7 @@ Configure failed, not sure why (see output above).""" % out
             shared_libs = []
 
         custom_paths = {
-                        'files': ["include/%s" % x for x in ["cblas.h", "clapack.h"]] + 
+                        'files': ["include/%s" % x for x in ["cblas.h", "clapack.h"]] +
                                  static_libs + shared_libs,
                         'dirs': ["include/atlas"]
                        }
