@@ -37,31 +37,38 @@ from distutils.version import LooseVersion
 
 import easybuild.tools.environment as env
 import easybuild.tools.toolchain as toolchain
+from easybuild.easyblocks.generic.cmakemake import CMakeMake
 from easybuild.easyblocks.generic.configuremake import ConfigureMake
 from easybuild.tools.modules import get_software_root, get_software_version
 
 
-class EB_netCDF(ConfigureMake):
+class EB_netCDF(CMakeMake):
     """Support for building/installing netCDF"""
 
     def configure_step(self):
         """Configure build: set config options and configure"""
 
-        self.cfg.update('configopts', "--enable-shared")
+        if LooseVersion(self.version) < LooseVersion("4.3"):
+            self.cfg.update('configopts', "--enable-shared")
 
-        if self.toolchain.options['pic']:
-            self.cfg.update('configopts', '--with-pic')
+            if self.toolchain.options['pic']:
+                self.cfg.update('configopts', '--with-pic')
 
-        self.cfg.update('configopts', 'FCFLAGS="%s" CC="%s" FC="%s"' % (os.getenv('FFLAGS'),
-                                                                       os.getenv('MPICC'),
-                                                                       os.getenv('F90')
-                                                                      ))
+            tup = (os.getenv('FFLAGS'), os.getenv('MPICC'), os.getenv('F90'))
+            self.cfg.update('configopts', 'FCFLAGS="%s" CC="%s" FC="%s"' % tup)
 
-        # add -DgFortran to CPPFLAGS when building with GCC
-        if self.toolchain.comp_family() == toolchain.GCC:  #@UndefinedVariable
-            self.cfg.update('configopts', 'CPPFLAGS="%s -DgFortran"' % os.getenv('CPPFLAGS'))
+            # add -DgFortran to CPPFLAGS when building with GCC
+            if self.toolchain.comp_family() == toolchain.GCC:  #@UndefinedVariable
+                self.cfg.update('configopts', 'CPPFLAGS="%s -DgFortran"' % os.getenv('CPPFLAGS'))
 
-        super(EB_netCDF, self).configure_step()
+            ConfigureMake.configure_step(self)
+
+        else:
+            hdf5 = get_software_root('HDF5')
+            if hdf5:
+                env.setvar('HDF5_ROOT', hdf5)
+
+            CMakeMake.configure_step(self)
 
     def sanity_check_step(self):
         """
